@@ -1,6 +1,6 @@
-from Orange.bio import obiGEO
+import Orange
 
-gds = obiGEO.GDS("GDS1676")
+gds = Orange.bio.geo.GDS("GDS1676")
 data = gds.getdata(sample_type="infection")
 print "Genes: %d, Samples: %d" % (len(data), len(data.domain.attributes))
 
